@@ -46,9 +46,10 @@ def mapstar(args):
 #
 
 class Introspector(threading.Thread):
-    def __init__(self, conn, *args, **kwargs):
+    def __init__(self, conn, worker_thread_id, *args, **kwargs):
         threading.Thread.__init__(self, *args, **kwargs)
         self._conn = conn
+        self.worker_thread_id = worker_thread_id
         
     def run(self):
 
@@ -59,11 +60,14 @@ class Introspector(threading.Thread):
         import traceback
         current_thread = threading.current_thread().ident
         try:
+            import os
             stack = None
+            res = []
             for id, stack in sys._current_frames().items():
-                if id == current_thread:
+                if id != self.worker_thread_id:
                     continue
-                return ''.join(traceback.format_stack(stack))
+                header = 'Worker (pid: %d)\n' % os.getpid()
+                return header + ''.join(traceback.format_stack(stack))
         finally:
             del stack
 
@@ -75,7 +79,7 @@ class Introspector(threading.Thread):
 def worker(conn, inqueue, outqueue, initializer=None, initargs=(), maxtasks=None):
     assert maxtasks is None or (type(maxtasks) == int and maxtasks > 0)
     
-    introspector = Introspector(conn)
+    introspector = Introspector(conn, threading.current_thread().ident)
     introspector.daemon = True
     introspector.start()
     
